@@ -40,4 +40,12 @@ class FlatMapStrategy(SearchStrategy):
 
     def do_draw(self, data):
         source = data.draw(self.flatmapped_strategy)
+        data.mark_bind()
         return data.draw(self.expand(source))
+
+    @property
+    def branches(self):
+        return [
+            FlatMapStrategy(strategy=strategy, expand=self.expand)
+            for strategy in self.flatmapped_strategy.branches
+        ]
